@@ -220,6 +220,7 @@ def pyrogram_api():
             delete_supergroup
             delete_user_history
             set_slow_mode
+            mark_chat_unread
         """,
         users="""
         Users
@@ -475,6 +476,7 @@ def pyrogram_api():
             Chat.add_members
             Chat.join
             Chat.leave
+            Chat.mark_unread
         """,
         user="""
         User
